"""Vision Functions.

The following function will allow you to update your Vision Client
project using scripting.
"""


def updateProject():
    # type: () -> None
    """Updates the Vision Client project with saved changes.

    This function is intended to be used in conjunction with the "None"
    option of Vision Project update modes in the Project Properties, and
    the Vision Client System Tag ProjectUpdateAvailable.
    """
    pass
